==> localnews-user-service-1.0.3-sources.jar: com/bxm/localnews/user/service/impl/AccountServiceImpl.java <==
package com.bxm.localnews.user.service.impl;

import java.math.BigDecimal;
import java.util.Date;

import com.alibaba.fastjson.JSON;
import com.bxm.localnews.user.constant.DeductPointStatusEnum;
import com.bxm.localnews.user.domain.PointOrderMapper;
import com.bxm.localnews.user.domain.UserAccountMapper;
import com.bxm.localnews.user.enums.GoldEnum;
import com.bxm.localnews.user.enums.GoldFlowTypeEnum;
import com.bxm.localnews.user.param.AccountGoldParam;
import com.bxm.localnews.user.param.DeductPointParam;
import com.bxm.localnews.user.param.StoreNeceParam;
import com.bxm.localnews.user.service.AccountService;
import com.bxm.localnews.user.service.UserAccountService;
import com.bxm.localnews.user.vo.PointOrder;
import com.bxm.localnews.user.vo.UserAccount;

import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @author zhaoyadong 2019/3/14 20:51
 * @desc
 */
@Slf4j
@Service
public class AccountServiceImpl implements AccountService {

    @Autowired
    private UserAccountMapper userAccountMapper;

    @Autowired
    private PointOrderMapper pointOrderMapper;

    @Autowired
    private UserAccountService userAccountService;

    @Override
    public BigDecimal selectGoldByUserId(StoreNeceParam storeNeceParam) {
        BigDecimal point = selectUsableGoldByUserId(Long.valueOf(storeNeceParam.getAppUid()));
        return point;
    }

    @Override
    public Boolean deductUserGold(DeductPointParam deductPointParam) {
        //保存订单记录
        PointOrder pointOrder = addPointOrder(deductPointParam);

        //获取用户金币
        BigDecimal userBalance = selectUsableGoldByUserId(Long.valueOf(deductPointParam.getAppUid()));

        //比较扣除的金币
        BigDecimal deductPoint = new BigDecimal(deductPointParam.getPoint().longValue());
        if (userBalance.compareTo(deductPoint) < 0) {
            return Boolean.FALSE;
        }
        log.debug("扣除金币传入的参数:[{}]", JSON.toJSONString(deductPointParam));
        AccountGoldParam param = new AccountGoldParam(Long.valueOf(deductPointParam.getAppUid()),
                GoldEnum.CONSUME_GOLD.name(), false, Math.abs(deductPoint.intValue()), pointOrder.getId(),
                GoldFlowTypeEnum.EXCHANGE_GOODS.getName());

        userAccountService.addGold(param);
        return true;
    }

    @Override
    public void deductConfirmUserGold(DeductPointParam deductPointParam) {

        //获取订单信息
        PointOrder pointOrder = pointOrderMapper.getPointOrder(Long.valueOf(deductPointParam.getAppUid()),
                deductPointParam.getOrderNum());
        if (pointOrder != null) {

            String status = DeductPointStatusEnum.getStatusByStatus(deductPointParam.getStatus());
            if (DeductPointStatusEnum.FAIL.getStatus().equals(status)) {
                //返还用户金币
                log.info("用户[{}]积分商城金币退回.......", deductPointParam.getAppUid());
                BigDecimal returnGold = new BigDecimal("-" + pointOrder.getDeductBalance());
                AccountGoldParam param = new AccountGoldParam(Long.valueOf(deductPointParam.getAppUid()),
                        GoldEnum.USABLE_GOLD.name(), false, returnGold.intValue(),
                        pointOrder.getId(),
                        GoldFlowTypeEnum.STORE_ADD_BALANCE.getName());
                userAccountService.addGold(param);
            }

            //更新订单信息
            pointOrder.setUpdateTime(new Date());
            pointOrder.setStatus(deductPointParam.getStatus());
            pointOrderMapper.updateByPrimaryKeySelective(pointOrder);
        }
    }

    @Override
    public void addUserGold(DeductPointParam deductPointParam) {
        //保存订单记录
        PointOrder pointOrder = addPointOrder(deductPointParam);

        //更新用户金币
        BigDecimal addPoint = new BigDecimal(deductPointParam.getPoint().longValue());
        AccountGoldParam param = new AccountGoldParam(Long.valueOf(deductPointParam.getAppUid()),
                GoldEnum.USABLE_GOLD.name(), true, addPoint.intValue(),
                pointOrder.getId(),
                GoldFlowTypeEnum.STORE_ADD_BALANCE.getName());
        userAccountService.addGold(param);
    }

    @Override
    public BigDecimal selectUsableGoldByUserId(Long userId) {
        UserAccount userAccount = userAccountMapper.getUserAccount(userId);
        if (null != userAccount) {
            BigDecimal usableGold = BigDecimal.valueOf(userAccount.getUsableGold());
            if (usableGold != null && usableGold.compareTo(new BigDecimal(0)) > 0) {
                return usableGold;
            } else {
                return BigDecimal.ZERO;
            }
        }
        return BigDecimal.ZERO;
    }

    /**
     * 添加订单记录
     *
     * @param deductPointParam
     * @return
     */
    private PointOrder addPointOrder(DeductPointParam deductPointParam) {
        PointOrder pointOrder = new PointOrder();
        pointOrder.setBxmOrderNo(deductPointParam.getOrderNum());
        pointOrder.setOrderNo(deductPointParam.getAppOrderNum());
        pointOrder.setUserId(Long.valueOf(deductPointParam.getAppUid()));
        pointOrder.setDeductBalance(deductPointParam.getPoint().longValue());
        pointOrder.setDescription(deductPointParam.getDescription());
        pointOrder.setStatus(deductPointParam.getStatus());
        pointOrder.setCreateTime(new Date());
        pointOrderMapper.insertSelective(pointOrder);

        return pointOrder;
    }
}

==> localnews-user-service-1.0.8-sources.jar: com/bxm/localnews/user/service/impl/AccountServiceImpl.java <==
package com.bxm.localnews.user.service.impl;

import com.alibaba.fastjson.JSON;
import com.bxm.localnews.user.constant.DeductPointStatusEnum;
import com.bxm.localnews.user.domain.PointOrderMapper;
import com.bxm.localnews.user.domain.UserAccountMapper;
import com.bxm.localnews.user.enums.GoldEnum;
import com.bxm.localnews.user.enums.GoldFlowTypeEnum;
import com.bxm.localnews.user.param.AccountGoldParam;
import com.bxm.localnews.user.param.DeductPointParam;
import com.bxm.localnews.user.param.StoreNeceParam;
import com.bxm.localnews.user.service.AccountService;
import com.bxm.localnews.user.service.UserAccountService;
import com.bxm.localnews.user.vo.PointOrder;
import com.bxm.localnews.user.vo.UserAccount;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @author zhaoyadong 2019/3/14 20:51
 * @desc
 */
@Slf4j
@Service
public class AccountServiceImpl implements AccountService {

    @Resource
    private UserAccountMapper userAccountMapper;

    @Resource
    private PointOrderMapper pointOrderMapper;

    @Resource
    private UserAccountService userAccountService;

    @Override
    public BigDecimal selectGoldByUserId(StoreNeceParam storeNeceParam) {
        return selectUsableGoldByUserId(Long.valueOf(storeNeceParam.getAppUid()));
    }

    @Override
    public Boolean deductUserGold(DeductPointParam deductPointParam) {
        //保存订单记录
        PointOrder pointOrder = addPointOrder(deductPointParam);

        //获取用户金币
        BigDecimal userBalance = selectUsableGoldByUserId(Long.valueOf(deductPointParam.getAppUid()));

        //比较扣除的金币
        BigDecimal deductPoint = new BigDecimal(deductPointParam.getPoint().longValue());
        if (userBalance.compareTo(deductPoint) < 0) {
            return Boolean.FALSE;
        }
        log.debug("扣除金币传入的参数:[{}]", JSON.toJSONString(deductPointParam));
        AccountGoldParam param = new AccountGoldParam(Long.valueOf(deductPointParam.getAppUid()),
                GoldEnum.CONSUME_GOLD.name(), false, Math.abs(deductPoint.intValue()), pointOrder.getId(),
                GoldFlowTypeEnum.EXCHANGE_GOODS.getName());

        userAccountService.addGold(param);
        return true;
    }

    @Override
    public void deductConfirmUserGold(DeductPointParam deductPointParam) {
        //获取订单信息
        PointOrder pointOrder = pointOrderMapper.getPointOrder(Long.valueOf(deductPointParam.getAppUid()),
                deductPointParam.getOrderNum());

        if (pointOrder != null) {
            String status = DeductPointStatusEnum.getStatusByStatus(deductPointParam.getStatus());
            if (DeductPointStatusEnum.FAIL.getStatus().equals(status)) {
                //返还用户金币
                log.info("用户[{}]积分商城金币退回.......", deductPointParam.getAppUid());
                BigDecimal returnGold = new BigDecimal("-" + pointOrder.getDeductBalance());
                AccountGoldParam param = new AccountGoldParam(Long.valueOf(deductPointParam.getAppUid()),
                        GoldEnum.USABLE_GOLD.name(), false, returnGold.intValue(),
                        pointOrder.getId(),
                        GoldFlowTypeEnum.STORE_ADD_BALANCE.getName());
                userAccountService.addGold(param);
            }

            //更新订单信息
            pointOrder.setUpdateTime(new Date());
            pointOrder.setStatus(deductPointParam.getStatus());
            pointOrderMapper.updateByPrimaryKeySelective(pointOrder);
        }
    }

    @Override
    public void addUserGold(DeductPointParam deductPointParam) {
        //保存订单记录
        PointOrder pointOrder = addPointOrder(deductPointParam);

        //更新用户金币
        BigDecimal addPoint = new BigDecimal(deductPointParam.getPoint().longValue());
        AccountGoldParam param = new AccountGoldParam(Long.valueOf(deductPointParam.getAppUid()),
                GoldEnum.USABLE_GOLD.name(), true, addPoint.intValue(),
                pointOrder.getId(),
                GoldFlowTypeEnum.STORE_ADD_BALANCE.getName());
        userAccountService.addGold(param);
    }

    @Override
    public BigDecimal selectUsableGoldByUserId(Long userId) {
        UserAccount userAccount = userAccountMapper.getUserAccount(userId);
        if (null != userAccount) {
            BigDecimal usableGold = BigDecimal.valueOf(userAccount.getUsableGold());
            if (usableGold != null && usableGold.compareTo(BigDecimal.ZERO) > 0) {
                return usableGold;
            } else {
                return BigDecimal.ZERO;
            }
        }
        return BigDecimal.ZERO;
    }

    /**
     * 添加订单记录
     *
     * @param deductPointParam
     * @return
     */
    private PointOrder addPointOrder(DeductPointParam deductPointParam) {
        PointOrder pointOrder = new PointOrder();
        pointOrder.setBxmOrderNo(deductPointParam.getOrderNum());
        pointOrder.setOrderNo(deductPointParam.getAppOrderNum());
        pointOrder.setUserId(Long.valueOf(deductPointParam.getAppUid()));
        pointOrder.setDeductBalance(deductPointParam.getPoint().longValue());
        pointOrder.setDescription(deductPointParam.getDescription());
        pointOrder.setStatus(deductPointParam.getStatus());
        pointOrder.setCreateTime(new Date());
        pointOrderMapper.insertSelective(pointOrder);

        return pointOrder;
    }
}
